@@ -33,7 +33,7 @@
 #' @param \dots Further arguments passed to or from other methods.
 #' @return  Returns GCCV score calculated for input parameters.  
 #' @author Manuel Febrero-Bande, Manuel Oviedo de la Fuente
-#' \email{manuel.oviedo@@usc.es}
+#' \email{manuel.oviedo@@udc.es}
 #' @seealso See Also as \code{\link{optim.np}}. \cr Alternative method
 #' (independent case): \code{\link{GCV.S}}
 #' @references Carmack, P. S., Spence, J. S., and Schucany, W. R. (2012).
@@ -87,8 +87,7 @@ GCCV.S=function(y,S,criteria="GCCV1",W=NULL,trim=0,draw=FALSE,metric=metric.lp,.
          y.est=t(S%*%y2)
          y.est<-fdata(y.est,y$argvals, y$rangeval, y$names)
          e <- y - y.est
-#         e$data<-sqrt(W)%*%(e$data)   
-         ee <- drop(norm.fdata(e,metric=metric,...)[,1]^2)
+		 ee <- norm.fdata(e,metric=metric,...)^2
          if (trim>0) {
             e.trunc=quantile(ee,probs=(1-trim),na.rm=TRUE,type=4)
             ind<-ee<=e.trunc
