@@ -26,14 +26,14 @@
 #' 
 #' @return { Returns GCV score calculated for input parameters.  }
 #' @author Manuel Febrero-Bande, Manuel Oviedo de la Fuente
-#' \email{manuel.oviedo@@usc.es}
+#' \email{manuel.oviedo@@udc.es}
 #' @seealso See Also as \code{\link{optim.np}} \cr Alternative method:
 #' \code{\link{CV.S}}
 #' @references 
 #' Wasserman, L. \emph{All of Nonparametric Statistics}. Springer Texts in Statistics, 2006. 
 #' Hardle, W. \emph{Applied Nonparametric Regression}. Cambridge University Press, 1994.
 #' Febrero-Bande,  M., Oviedo de la Fuente, M. (2012).  \emph{Statistical Computing in Functional Data Analysis: The R Package fda.usc.}
-#' Journal of Statistical Software, 51(4), 1-28. \url{http://www.jstatsoft.org/v51/i04/}
+#' Journal of Statistical Software, 51(4), 1-28. \url{https://www.jstatsoft.org/v51/i04/}
 #' @keywords utilities
 #' @examples
 #' \dontrun{
@@ -61,9 +61,8 @@ GCV.S=function(y,S,criteria="GCV",W=NULL,trim=0,draw=FALSE,metric=metric.lp,...)
          y2=t(y$data)
          y.est=t(S%*%y2)
          y.est<-fdata(y.est,y$argvals, y$rangeval, y$names)
-         e <- y - y.est
-#         e$data<-sqrt(W)%*%(e$data)   
-         ee <- drop(norm.fdata(e,metric=metric,...)[,1]^2)
+         e <- y - y.est   
+         ee <- norm.fdata(e,metric=metric,...)^2
          if (trim>0) {
             e.trunc=quantile(ee,probs=(1-trim),na.rm=TRUE,type=4)
             ind<-ee<=e.trunc
