@@ -12,19 +12,24 @@
 #' @param basis.b List of basis for \eqn{\beta(t)} parameter estimation.
 #' @param rn List of Ridge parameter.
 #' @param lambda List of Roughness penalty parameter.
-#' @param correlation an optional \code{\link{corStruct}} object describing the
-#' within-group correlation structure. See the documentation of
-#' \code{\link{corClasses}} for a description of the available \code{corStruct}
-#' classes. If a grouping variable is to be used, it must be specified in
-#' the \code{form} argument to the \code{corStruct} constructor. Defaults to 
+#' @param weights weights
+#' @param correlation List  describing the  correlation structure. Defaults to 
 #' \code{NULL}, corresponding to uncorrelated errors.
+#' See the following internal functions  for a description and a code example in script file.
+#' \itemize{
+#' \item \code{corUnstruc(x)}, fit an unstrutured correlation.
+#' \item \code{cor.AR(x, order.max = 8, p=1, method = "lm")} fit an Autoregressive Models to Time Series using \code{\link{ar}} function.
+#' \item \code{cor.ARMA(x, p, d = 0, q = 0, method = "lm", order.max = 1)} Fit an ARIMA model to a univariate time series using \code{\link{arima}} function.
+#' \item \code{corExpo(xy,range, method = "euclidean",p=2)} Fit an exponential correlation structure.
+#' }
+ 
 #' @param maxit Number of maximum of interactions.
-#' @param weights An optional \code{\link{varFunc}} object or one-sided formula
-#'  describing the within-group heteroscedasticity structure. If given as
-#'  a formula, it is used as the argument to \code{\link{varFixed}},
-#'  corresponding to fixed variance weights. See the documentation on
-#'  \code{\link{varClasses}} for a description of the available \code{\link{varFunc}}
-#'  classes. Defaults to \code{NULL}, corresponding to homoscedastic errors.
+# @param weights An optional \code{\link{varFunc}} object or one-sided formula
+#  describing the within-group heteroscedasticity structure. If given as
+#  a formula, it is used as the argument to \code{\link{varFixed}},
+#  corresponding to fixed variance weights. See the documentation on
+#  \code{\link{varClasses}} for a description of the available \code{\link{varFunc}}
+#  classes. Defaults to \code{NULL}, corresponding to homoscedastic errors.
 #' @param control Control parameters.  
 #' @param \dots Further arguments passed to or from other methods.
 
@@ -39,35 +44,22 @@
 #'  dependence structure chosen.
 #' \item Repeats steps 2 and 3 until convergence (small changes in \eqn{b_\Sigma} and/or \eqn{\hat{\theta}}). 
 #' }
-#' @return An object of class \code{"gls"} representing the functional linear model
-#' fit. Generic functions such as \code{print}, \code{plot}, and \code{summary} have
-#' methods to show the results of the fit. 
-#' 
-#'  See \code{\link{glsObject}} for the components of the fit. The functions
-#'  \code{\link{resid}}, \code{\link{coef}} and \code{\link{fitted}}, can be used to
-#'   extract some of its components. 
-#' Beside, the class(z) is  "gls", "lm" and "fregre.lm" with the following objects:
+#' @return An object of class \code{"fregre.igls"} representing the functional linear model
+#' fit with temporal dependence errors.
+#' Beside, the class(z) is  similar to "fregre.lm" plus the following objects:
 #' \itemize{
-#'  \item{sr2}{ Residual variance.}
-#'  \item{Vp}{ Estimated covariance matrix for the parameters.}
-#'  \item{lambda}{ A roughness penalty.}	
-#'  \item{basis.x}{ Basis used for \code{fdata} or \code{fd} covariates.}
-#'  \item{basis.b}{ Basis used for beta parameter estimation.}
-#'  \item{beta.l}{ List of estimated beta parameter of functional covariates.}
-#'  \item{data}{ List that containing the variables in the model.}
-#'  \item{formula}{ formula used in ajusted model.}
-#'  \item{formula.ini}{ formula in call.}
-#'  \item{XX}{ desing matrix }
-#'  \item{W}{ inverse of covariance matrix}
-#'  \item{fdataob}{ }
-#'  \item{rn}{ rn}
-#'  \item{vs.list}{ }
-#'  \item{correlation}{ See glsObject for the components of the fit. }
+#'  \item{corStruct}{ Fitted  AR or ARIMA model.  }
+#  \item{formula.ini}{ formula in call.}
+#  \item{fdataob}{ }
+#  \item{rn}{ rn}
+#  \item{vs.list}{ }
+#  \item{correlation}{  }
 #'  }
-#' @references  Oviedo de la Fuente, M., Febrero-Bande, M., Pilar Munoz,
-#' and Dominguez, A. Predicting seasonal influenza transmission using Functional 
-#' Regression Models with Temporal Dependence. arXiv:1610.08718.
-#'  \url{https://arxiv.org/abs/1610.08718}
+#'  
+#' @references Oviedo de la Fuente, M., Febrero-Bande, M., Pilar Munoz, and
+#' Dominguez, A.  (2018). Predicting seasonal influenza transmission using 
+#' functional regression models with temporal dependence. PloS one, 13(4), e0194250.
+#' \doi{10.1371/journal.pone.0194250}
 #' @examples
 #' \dontrun{ 
 #' data(tecator)
@@ -229,8 +221,8 @@ fregre.igls<-function (formula, data, basis.x = NULL, basis.b = NULL, correlatio
           basis <- basis.x[[vfunc[i]]]
           l <- basis$l
           vs <- t(basis$basis$data)
-          basis$x <- basis$x[, l, drop = FALSE]
-          Z <- basis$x
+          basis$coefs <- basis$coefs[, l, drop = FALSE]
+          Z <- basis$coefs
           response = "y"
           colnames(Z) = name.coef[[vfunc[i]]] = paste(vfunc[i], 
                                                       ".", rownames(basis$basis$data), sep = "")
@@ -270,14 +262,14 @@ fregre.igls<-function (formula, data, basis.x = NULL, basis.b = NULL, correlatio
           fdat <- data[[vfunc[i]]]
           if (is.null(basis.x[[vfunc[i]]])) 
             basis.x[[vfunc[i]]] <- fdat$basis
-          else if (class(basis.x[[vfunc[i]]]) == "pca.fd") 
+          else if (inherits(basis.x[[vfunc[i]]], "pca.fd")) 
             bsp1 = FALSE
           if (is.null(basis.b[[vfunc[i]]]) & bsp1) 
             basis.b[[vfunc[i]]] <- create.fdata.basis(fdat, 
                                                       l = 1:max(5, floor(basis.x[[vfunc[i]]]$nbasis/5)), 
                                                       type.basis = basis.x[[vfunc[i]]]$type, 
                                                       rangeval = fdat$basis$rangeval)
-          else if (class(basis.x[[vfunc[i]]]) == "pca.fd") 
+          else if (inherits(basis.x[[vfunc[i]]], "pca.fd")) 
             bsp2 = FALSE
           if (bsp1 & bsp2) {
             r = fdat[[2]][[3]]
@@ -674,7 +666,7 @@ fregre.igls<-function (formula, data, basis.x = NULL, basis.b = NULL, correlatio
       beta.l[[vfunc[i]]] = fd(z$coefficients[name.coef[[vfunc[i]]]], 
                               basis.b[[vfunc[i]]])
     else {
-      if (class(data[[vfunc[i]]])[1] == "fdata") {
+      if (inherits(data[[vfunc[i]]], "fdata")) {
         beta.est <- z$coefficients[name.coef[[vfunc[i]]]] * 
           vs.list[[vfunc[i]]]
         beta.est$data <- colSums(beta.est$data)
