@@ -39,7 +39,7 @@
 #' \item {fitted.values}{ Estimated scalar response.} 
 #' \item {H}{ Hat matrix.} 
 #' \item {residuals}{ \code{y} minus \code{fitted values}.} 
-#' \item {df}{ The residual degrees of freedom.} 
+#' \item {df.residual}{ The residual degrees of freedom.} 
 #' \item {r2}{ Coefficient of determination.} 
 #' \item {sr2}{ Residual variance.} 
 #' \item {y}{ Response.} 
@@ -49,7 +49,7 @@
 #' \item {h.opt}{ smoothing parameter or' bandwidth.}
 #' }
 #' @author Manuel Febrero-Bande, Manuel Oviedo de la Fuente
-#' \email{manuel.oviedo@@usc.es}
+#' \email{manuel.oviedo@@udc.es}
 #' @seealso See Also as: \code{\link{fregre.np.cv}},
 #' \code{\link{summary.fregre.fd}} and \code{\link{predict.fregre.fd}} .\cr
 #' Alternative method: \code{\link{fregre.basis}},cand \code{\link{fregre.pc}}.
@@ -58,7 +58,7 @@
 #' 
 #' Febrero-Bande, M., Oviedo de la Fuente, M. (2012).  \emph{Statistical
 #' Computing in Functional Data Analysis: The R Package fda.usc.} Journal of
-#' Statistical Software, 51(4), 1-28. \url{http://www.jstatsoft.org/v51/i04/}
+#' Statistical Software, 51(4), 1-28. \url{https://www.jstatsoft.org/v51/i04/}
 #' 
 #' Hardle, W. \emph{Applied Nonparametric Regression}. Cambridge University
 #' Press, 1994.
@@ -97,7 +97,7 @@ fregre.np<-function(fdataobj,y,h=NULL,Ker=AKer.norm,
 isfdata<-is.fdata(y)
 nas<-is.na.fdata(fdataobj)
 nas.g<-is.na(y)
-if (is.null(names(y))) names(y)<-1:length(y)
+if (is.null(names(y))) names(y)<-seq_len(length(y))
 if (any(nas) & !any(nas.g)) {
    bb<-!nas
    cat("Warning: ",sum(nas)," curves with NA are omited\n")
@@ -120,12 +120,12 @@ if (any(nas) & any(nas.g))  {
    }
 }}                              
 x<-fdataobj[["data"]]
-tt<-fdataobj[["argvals"]]
-rtt<-fdataobj[["rangeval"]]
+#tt<-fdataobj[["argvals"]]
+#rtt<-fdataobj[["rangeval"]]
 C<-match.call()
 mf <- match.call(expand.dots = FALSE)
 m<-match(c("fdataobj", "y","h","Ker","metric","type.S","par.S"),names(mf),0L)
-#    if (is.vector(x))         x <- t(as.matrix(x))
+#    if (is.vector(x))         x <- t(data.matrix(x))
 n = nrow(x)
 np <- ncol(x)   
    if (!isfdata) {
@@ -133,7 +133,7 @@ np <- ncol(x)
    if (is.null(rownames(x)))         rownames(x) <- 1:n
    if (is.null(colnames(x)))         colnames(x) <- 1:np
    if (is.vector(y)) y.mat<-matrix(y,ncol=1)
-   else y.mat<-as.matrix(y)
+   else y.mat<-data.matrix(y)
    ny = nrow(y.mat)
    npy <- ncol(y.mat)
    }
@@ -148,15 +148,20 @@ np <- ncol(x)
 
 if (is.matrix(metric)) mdist<-metric
 else mdist=metric(fdataobj,fdataobj,...)
-ke<-deparse(substitute(Ker))
+#ke<-deparse(substitute(Ker))
+#if (!is.function(Ker)) Ker<-get(Ker)
+
+
+# if (is.character(Ker)){  nker <- function(u,mik=Ker){get(mik)(u)}
+# } else {  nker <- function(u,mik=Ker){mik(u)} }
+
 ty<-deparse(substitute(type.S))
 attr(par.S, "call") <- ty
 #print(h)
-if (is.null(h)) h=h.default(fdataobj,prob=0.05,len=1,metric = mdist, type.S = ty,...)
-#     H =type.S(mdist,h,Ker,cv=FALSE)
-#     par.S$w<-y
-#S.NW2<-function (tt, h, Ker = Ker.norm,cv=FALSE,weights=rep(1,len=length(tt)))
-#    print(H[1:2,1:3]);    print(ty)
+if (is.null(h)) {
+#      nker=get(paste0("Ker.",unlist(strsplit(deparse(substitute(Ker)),"[.]"))[2]))
+      h=h.default(fdataobj,prob=0.1,len=1,metric = mdist, type.S = ty, Ker=Ker,...)
+    }
     par.S$tt<-mdist
     if (is.null(par.S$Ker))  par.S$Ker<-Ker
     if (is.null(par.S$h))  par.S$h<-h
@@ -183,11 +188,11 @@ if (is.null(h)) h=h.default(fdataobj,prob=0.05,len=1,metric = mdist, type.S = ty
 #      sr2=sum(e^2)/(n-df)
       ycen=fdata.cen(y)$Xcen
 #  	  r2=1-sum(e^2)/sum(ycen^2)
-    norm.e<-norm.fdata(e,metric=metric,...)[,1]^2
+    norm.e<-norm.fdata(e,metric=metric,...)^2
     sr2=sum(norm.e)/(n-df)
     ycen=fdata.cen(y)$Xcen
  	  r2=1-sum(norm.e)/sum(ycen^2)
-      out<-list("call"=C,"fitted.values"=yp,"H"=H,"residuals"=e,"df"=df,"r2"=r2,
+      out<-list("call"=C,"fitted.values"=yp,"H"=H,"residuals"=e,"df.residual"=df,"r2"=r2,
 "sr2"=sr2,"y"=y,"fdataobj"=fdataobj,"mdist"=mdist,"Ker"=Ker,
 "metric"=metric,"type.S"=type.S,"par.S"=par.S,"h.opt"=h,"m"=m)
       }
@@ -199,7 +204,7 @@ else {
     sr2=sum(e^2)/(n-df)
     ycen=y-mean(y)
 	  r2=1-sum(e^2)/sum(ycen^2)
-	  out<-list("call"=C,"fitted.values"=yp,"H"=H,"residuals"=e,"df"=df,"r2"=r2,
+	  out<-list("call"=C,"fitted.values"=yp,"H"=H,"residuals"=e,"df.residual"=df,"r2"=r2,
 "sr2"=sr2,"y"=drop(y),"fdataobj"=fdataobj,"mdist"=mdist,"Ker"=Ker,
 "metric"=metric,"type.S"=type.S,"par.S"=par.S,"h.opt"=h,"m"=m,var.y=yp2)
   }
