@@ -64,7 +64,7 @@
 #' \item {df}{ degrees of freedom for residual.}
 #' }
 #' @author Manuel Febrero-Bande, Manuel Oviedo de la Fuente
-#' \email{manuel.oviedo@@usc.es}
+#' \email{manuel.oviedo@@udc.es}
 #' 
 #' @seealso See Also as: \code{\link{fregre.lm}}, \code{\link{fregre.plm}},
 #' \code{\link{fregre.glm}}, \code{\link{fregre.gsam}} and
@@ -73,44 +73,39 @@
 #' @references Febrero-Bande, M., Oviedo de la Fuente, M. (2012).
 #' \emph{Statistical Computing in Functional Data Analysis: The R Package
 #' fda.usc.} Journal of Statistical Software, 51(4), 1-28.
-#' \url{http://www.jstatsoft.org/v51/i04/}
+#' \url{https://www.jstatsoft.org/v51/i04/}
 #' 
 #' @keywords regression
 #' @examples
 #' \dontrun{
 #' data(tecator)
-#' ind<-1:129
-#' x=tecator$absorp.fdata
-#' x.d2<-fdata.deriv(x,nderiv=2)
-#' tt<-x[["argvals"]]
-#' dataf=as.data.frame(tecator$y)
-#' nbasis.x=11;nbasis.b=7
-#' basis1=create.bspline.basis(rangeval=range(tt),nbasis=nbasis.x)
-#' basis2=create.bspline.basis(rangeval=range(tt),nbasis=nbasis.b)
-#' basis.x=list("x.d2"=basis1)
-#' basis.b=list("x.d2"=basis2)
-#' ldata=list("df"=dataf[ind,],"x.d2"=x.d2[ind])
-#' 
-#' res=fregre.gsam(Fat~s(Water,k=3)+s(x.d2,k=3),data=ldata,
-#' family=gaussian(),basis.x=basis.x,basis.b=basis.b)
-#' newldata=list("df"=dataf[-ind,],"x.d2"=x.d2[-ind])
-#' pred<-predict(res,newldata)
+#' ind <- 1:129
+#' x <- tecator$absorp.fdata
+#' x.d2 <- fdata.deriv(x,nderiv=2)
+#' tt <- x[["argvals"]]
+#' dataf <- as.data.frame(tecator$y)
+#' ldat <- ldata("df" = dataf[ind,], "x.d2" = x.d2[ind])
+#' basis.x <- list("x.d2" = create.pc.basis(ldat$x.d2))
+#' res <- fregre.gsam(Fat ~  s(x.d2,k=3),
+#'                    data=ldat, family = gaussian(),
+#'                    basis.x = basis.x)
+#' newldat <- ldata("df" = dataf[-ind,], "x.d2" = x.d2[-ind])
+#' pred <- predict(res, newldat)
 #' plot(pred,tecator$y$Fat[-ind])
-#' 
-#' res.glm=fregre.glm(Fat~Water+x.d2,data=ldata,family=gaussian(),
-#' basis.x=basis.x,basis.b=basis.b)
-#' pred.glm<-predict(res.glm,newldata)
-#' newy<-tecator$y$Fat[-ind]
+#' res.glm <- fregre.glm(Fat  ~  x.d2, data = ldat,
+#'                   family = gaussian(),basis.x = basis.x)
+#' pred.glm <- predict(res.glm, newldat)
+#' newy <- tecator$y$Fat[-ind]
 #' points(pred.glm,tecator$y$Fat[-ind],col=2)
 #' 
 #' # Time-consuming 
-#' res.gkam=fregre.gkam(Fat~x.d2,data=ldata)
-#' pred.gkam=predict(res.gkam,newldata)
-#' points(pred.gkam,tecator$y$Fat[-ind],col=4)
+#' res.gkam <- fregre.gkam(Fat ~ x.d2, data = ldat)
+#' pred.gkam <- predict(res.gkam, newldat)
+#' points(pred.gkam,tecator$y$Fat[-ind],col = 4)
 #' 
-#' ((1/length(newy))*sum((drop(newy)-pred)^2))/var(newy)
-#' ((1/length(newy))*sum((newy-pred.glm)^2))/var(newy)    
-#' ((1/length(newy))*sum((newy-pred.gkam)^2))/var(newy)    
+#' ((1/length(newy)) * sum((drop(newy)-pred)^2)) / var(newy)
+#' ((1/length(newy)) * sum((newy-pred.glm)^2)) / var(newy)    
+#' ((1/length(newy)) * sum((newy-pred.gkam)^2)) / var(newy)    
 #' }                                                                                                              
 #' @rdname predict.fregre.lm
 #' @export 
@@ -134,7 +129,8 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
     return(yp)
   }
   else {
-    data = newx
+    name.coef <- NULL
+#    data = newx
     basis.x = object$basis.x
     basis.b = object$basis.b
     formula = object$formula.ini
@@ -142,19 +138,20 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
     terms <- attr(tf, "term.labels")
     nt <- length(terms)
     vtab <- rownames(attr(tf, "factors"))
-    vnf = intersect(terms, names(data$df))
+    vnf = intersect(terms, names(newx$df))
     vfunc2 = setdiff(terms, vnf)
     vint = setdiff(terms, vtab)
     vfunc = setdiff(vfunc2, vint)
     off <- attr(tf, "offset")
     beta.l = list()
     kterms = 1
-    if (attr(tf, "response") > 0) {
-      response <- as.character(attr(tf, "variables")[2])
-      pf <- rf <- paste(response, "~", sep = "")
-    }
-    else pf <- rf <- "~"
-    if (attr(tf, "intercept") == 0) {
+#    if (attr(tf, "response") > 0) {
+#      response <- as.character(attr(tf, "variables")[2])
+#      pf <- rf <- paste(response, "~", sep = "")
+#    }
+#    else pf <- rf <- "~"
+    pf <- rf <- "~"  # En predicción no hace falta la respuesta en los datos nuevos
+    if (attr(tf, "intercept") == 0) { 
       print("No intecept")
       pf <- paste(pf, -1, sep = "")
     }
@@ -169,7 +166,7 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
       if (attr(tf, "intercept") == 0) {
         pf <- paste(pf, -1, sep = "")
       }
-      mf <- as.data.frame(model.matrix(formula(pf), data$df))
+      mf <- as.data.frame(model.matrix(formula(pf), newx$df))
       vnf2 <- names(mf)[-1]
       for (i in 1:length(vnf2)) pf <- paste(pf, "+", vnf2[i], 
                                             sep = "")
@@ -177,64 +174,55 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
     }
     else {
       pf2 <- paste(pf, "1", sep = "")
-      XX <- data.frame(model.matrix(formula(pf2), data$df))
+      XX <- data.frame(model.matrix(formula(pf2), newx$df))
       first = TRUE
     }
+    if (!is.null(newx$df)) nnew=nrow(newx$df) else  {
+      if (inherits(newx[[vfunc[1]]],"fdata")) nnew=nrow(newx[[vfunc[1]]]) else nnew=ncol(newx[[vfunc[1]]]$coefs)
+    }
     if (length(vnf) > 0) {
       spm <- matrix(object$coefficients[names(XX)], ncol = 1)
       yp <- as.matrix(XX) %*% spm
     }
-    else yp <- object$coefficients[1] * rep(1, len = nrow(newx[[vfunc[1]]]))
-    if (length(vfunc) > 0) {
-      for (i in 1:length(vfunc)) {
-       if (class(data[[vfunc[i]]])[1] == "fdata") {
-          fdataobj <- data[[vfunc[i]]]
-          x.fd <- fdataobj[["data"]]
-          tt <- fdataobj[["argvals"]]
-          rtt <- fdataobj[["rangeval"]]
-          if (!object$basis.x[[vfunc[i]]]$type == "pc" & 
-              !object$basis.x[[vfunc[i]]]$type == "pls") {
-           x.fd = Data2fd(argvals = tt, y = t(fdata.cen(fdataobj, 
-                          object$mean[[vfunc[i]]])[[1]]$data),
-                          basisobj = basis.x[[vfunc[i]]], 
-                           fdnames = rownames(x.fd))
-             r = x.fd[[2]][[3]]
-            J <- object$JJ[[vfunc[i]]]
-            Z = t(x.fd$coefs) %*% J
-            colnames(Z) = colnames(J)
+    else yp <- object$coefficients[1] * rep(1, len = nnew)
+    lenfunc <- length(vfunc)
+    if (lenfunc > 0) {
+      for (i in 1:lenfunc) {
+#        if (lenfunc>0) {
+#          k=1
+#          mean.list=vs.list=JJ=list()
+#          for (i in 1:lenfunc) {
+#            if(class(newx[[vfunc[i]]])[1]=="fdata"){
+            if(inherits(newx[[vfunc[i]]],"fdata")){
+#              tt<-data[[vfunc[i]]][["argvals"]]
+#              rtt<-data[[vfunc[i]]][["rangeval"]]
+              fdataobj<-newx[[vfunc[i]]]
+              fdat<-newx[[vfunc[i]]];      dat<-fdataobj$data
+#              if (nrow(dat)==1) rwn<-NULL         else rwn<-rownames(dat)
+              if (nrow(newx[[vfunc[i]]]$data)==1) rwn<-NULL else rwn<-rownames(newx[[vfunc[i]]]$data)
+              #  if (basis.x[[vfunc[i]]]$type=="pc" 
+              #      | basis.x[[vfunc[i]]]$type=="pls")
+              #    bsp1=FALSE      else bsp1 <- TRUE
+              xaux <- fdata2basis(newx[[vfunc[i]]],basis.x[[vfunc[i]]])
+
+              Z <- xaux$coefs%*%object$vs.list[[vfunc[i]]]
+#              colnames(Z)=colnames(object$vs.list[[vfunc[i]]])
+              name.coef[[vfunc[i]]] <- paste(vfunc[i],".",colnames(object$vs.list[[vfunc[i]]]),sep="")
+              colnames(Z)=name.coef[[vfunc[i]]]
+              if (first) {
+                XX=Z
+                first=FALSE
+              }   else {
+                XX = cbind(XX,Z)} 
           }
-          else {
-            name.coef <- paste(vfunc[i], ".", rownames(object$basis.x[[vfunc[i]]]$basis$data), 
-                               sep = "")
-            newXcen <- fdata.cen(fdataobj, object$mean[[vfunc[i]]])[[1]]
-            
-            
-            if (object$basis.x[[vfunc[i]]]$type == "pls") {
-              if (object$basis.x[[vfunc[i]]]$norm) {
-                sd.X <- sqrt(apply(object$basis.x[[vfunc[i]]]$fdataobj$data, 
-                                   2, var))
-                newXcen$data <- newXcen$data/(rep(1, 
-                                                  nrow(newXcen)) %*% t(sd.X))
-              }
-            }
-            Z <- inprod.fdata(newXcen, object$vs.list[[vfunc[i]]])
-            colnames(Z) <- name.coef
-          }
-          if (first) {
-            XX = Z
-            first = FALSE
-          }
-          else XX = cbind(XX, Z)
-        }
         else {
-          if (class(data[[vfunc[i]]])[1] == "fd") {
-            if (class(object$basis.x[[vfunc[i]]]) != 
-                "pca.fd") {
-              x.fd <- fdataobj <- data[[vfunc[i]]]
-              r = x.fd[[2]][[3]]
-              J <- object$JJ[[vfunc[i]]]
-              x.fd$coefs <- x.fd$coefs - object$mean[[vfunc[i]]]$coefs[, 
-                                                                       1]
+          if (inherits(newx[[vfunc[i]]], "fd")) {
+            if (!inherits(object$basis.x[[vfunc[i]]], "pca.fd")) {
+#              x.fd <- fdataobj <- data[[vfunc[i]]]
+              x.fd <- newx[[vfunc[i]]]
+              r = x.fd[["basis"]][["rangeval"]]
+              J <- object$vs.list[[vfunc[i]]]
+              x.fd$coefs <- x.fd$coefs - object$mean[[vfunc[i]]]$coefs[,1]
               Z = t(x.fd$coefs) %*% J
               colnames(Z) = colnames(J)
             }
@@ -242,10 +230,10 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
               name.coef[[vfunc[i]]] = paste(vfunc[i], 
                                             ".", colnames(object$basis.x[[vfunc[i]]]$harmonics$coefs), 
                                             sep = "")
-              data[[vfunc[i]]]$coefs <- sweep(data[[vfunc[i]]]$coefs, 
+              newx[[vfunc[i]]]$coefs <- sweep(newx[[vfunc[i]]]$coefs, 
                                               1, (object$basis.x[[vfunc[i]]]$meanfd$coefs), 
                                               FUN = "-")
-              fd.cen <- data[[vfunc[i]]]
+              fd.cen <- newx[[vfunc[i]]]
               Z <- inprod(fd.cen, object$basis.x[[vfunc[i]]]$harmonics)
               colnames(Z) <- name.coef[[vfunc[i]]]
             }
@@ -259,11 +247,12 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
         }
       }
     }
+
     nn <- nrow(XX)
     if (!is.data.frame(XX)) 
       XX = data.frame(XX)
-    if (!object$rn) {
-      
+    if (!object$lambda) {
+      res.var <- object$sr2
       if (type == "effects"){
         fake  = predict.lm(object, newdata = XX, type = "terms", se.fit = se.fit, 
                            interval = interval, level = level, weights = weights, 
@@ -278,7 +267,7 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
     }
     else {
       if (type!="response") warning("Only response type implemented for penalization")
-      for (i in 1:length(vfunc)) {
+      for (i in 1:lenfunc) {
         if (object$call[[1]] == "fregre.pls") 
           return(predict.lm(object = object, newdata = XX, 
                             type = type, se.fit = se.fit, ...))
@@ -294,10 +283,10 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
           x.fd = Data2fd(argvals = xcen$argvals, y = t(xcen$data), 
                          basisobj = object$basis.x[[vfunc[i]]])
           C = t(x.fd$coefs)
-          cnames <- colnames(object$JJ[[vfunc[i]]])
+          cnames <- colnames(object$vs.list[[vfunc[i]]])  #basis.list?
           b.est <- matrix(object$coefficients[cnames], 
                           ncol = 1)
-          b1 <- C %*% object$JJ[[vfunc[i]]] %*% b.est
+          b1 <- C %*% object$basis.list[[vfunc[i]]] %*% b.est
           yp <- yp + b1
         }
       }
@@ -328,10 +317,10 @@ predict.fregre.lm<-function (object, newx = NULL, type = "response", se.fit = FA
 }
 #################################
 #################################
-effect.fake <- function(object,terms){
+effect.fake <- function(object, terms){
   #fake<-predict(object,type = "terms")
   fake <- terms
-  vfunc <- names(object$JJ)
+  vfunc <- names(object$basis.list)
   nfunc <- length(vfunc)
   tr <- attr(object$terms,"term.labels")
   #effects.df <- intersect(tr,colnames(object$data$df))
@@ -339,14 +328,19 @@ effect.fake <- function(object,terms){
   effects<-NULL
   vf <- NULL
   for (i in 1:nfunc){
-    ifunc<-colnames(object$JJ[[i]])
+    ifunc<-colnames(object$basis.list[[i]])
     dfnames <- intersect(tr,ifunc)
     vf <- c(vf,dfnames)
-    effects<-cbind(effects,rowSums(fake[,dfnames,drop=F]))
+    effects<-cbind(effects,rowSums(fake[,dfnames, drop = F]))
   }
   colnames(effects)<-vfunc
   dfnames <- setdiff(tr,vf)
-  effects<-cbind(fake[,dfnames,drop=F],effects)
+  effects <- cbind(fake[,dfnames,drop=F], effects)
   effects  
 }
 #################################
+# Modification (2021/03/22)
+# Z <- inprod.fdata(newXcen, object$vs.list[[vfunc[i]]])
+# #Z <- inprod.fdata(newXcen, object$JJ[[vfunc[i]]])
+# if (!object$lambda)
+# # if (!object$rn)
\ No newline at end of file
